import enigma from 'enigma.js';
const qixSchema = require('./node_modules/enigma.js/schemas/qix/3.1/schema.json');
import Halyard from 'halyard.js/dist/halyard';
import halyardMixin from 'halyard.js/dist/halyard-enigma-mixin';
import getFBData from './fb.js';

const config = {
  schema: qixSchema,
  session: {
    host: 'localhost',
		prefix: '',
		port: 4848,
		unsecure: true,
    identity: new Date().valueOf()
  },
  mixins: halyardMixin
};

let halyardReady = new Promise(resolve => {
  const halyard = new Halyard();
  halyard.setDefaultSetStatements({MonthNames: 'Jan;Feb;Mar;Apr;May;Jun;Jul;Aug;Sep;Oct;Nov;Dec', DayNames: 'Mon;Tue;Wed;Thu;Fri;Sat;Sun'});
  getFBData.then(response => {
    $("#loading-message").html("Creating session app");
    const table = new Halyard.Table(response, {fields: [{src: 'created_time', name: 'created', calendarTemplate: true}, {expr: 'WeekDay(created_time)', name: 'Day'}, {expr: 'Hour(created_time)', name: 'Hour'}]});
    halyard.addTable(table);
    window.halyard = halyard;
    resolve(halyard);
  });
});

export default halyardReady.then((halyard) => { 
  return enigma.getService('qix', config).then((qix) => {
    return qix.global.createSessionAppUsingHalyard(halyard).then((app) => {
      return app;
    });
  });
});